@@ -1,11 +1,13 @@
 class AdminPermissionRequestDenied(Exception):
-        """ Set the Argument Variable 'show' to 'True' """
+    """ Set the Argument Variable 'show' to 'True' """
 class NoneTypeArgumentBool(Exception):
     """ The Variable For Argument 'show' Should be 'Boolean' Type """
 class NoneTypeArgumentInt(Exception):
     """ The Variable For Argument 'timeout' Should be 'Int' Type """
 class NoneTypeArgumentString(Exception):
     """ The Variable For Argument 'link' Should be 'String' Type """
+class NoneLinuxMethod(Exception):
+    """ This Method is not Used in Linux OS """
 class UndefinedOperatingSystem(Exception):
     """ The Operating System is Not Defined Yet """
 class UnrecognizeableTypeArgument(Exception):
